@@ -1,5 +1,5 @@
 package QBit::WebInterface::PSGI::Request;
-$QBit::WebInterface::PSGI::Request::VERSION = '0.002';
+$QBit::WebInterface::PSGI::Request::VERSION = '0.003';
 use qbit;
 
 use base qw(QBit::WebInterface::Request);
@@ -8,7 +8,8 @@ sub http_header {
     my ($self, $name) = @_;
 
     $name =~ s/-/_/g;
-    my $value = $self->{'ENV'}{'HTTP_' . uc($name)};
+    $name = uc($name);
+    my $value = $self->{'ENV'}{'HTTP_' . $name} // $self->{'ENV'}{$name};
 
     return defined($value) ? $value : '';
 }
